#! /bin/sh
# CentralBan Monitor 


server=<server> 		#Fill in Argus PAP banning service host name
mailto=<mail-address>		#Fill email address for alerts
statefile=<statefile>		#Fill name of statefile hosting current banlist	
statedir=<statefile-dir>	#Fill directory of statefile
papdump=<get-argus-denylist>  	#Fill command location
verbose=0

PATH=$HOME/bin:$PATH
export PATH
LANG=C
export LANG

while getopts 'vs:m:' option ; do
    case $option in
    m)  mailto==${OPTARG}
        ;;
    s)  server==${OPTARG}
        ;;
    v)  verbose=$(($verbose + 1))
        ;;
    *)  echo Invalid option $OPTARG >&2
        usage
        exit 1
        ;;
    esac
done
shift $(($OPTIND - 1))

TMPDIR=${TMPDIR:-/var/tmp}
export TMPDIR

tempfile=`mktemp --tmpdir cblist.$$.XXXXXX`
chmod 0600 $tempfile
$papdump $server > $tempfile
if [ ! -s $tempfile ]; then
  echo "$0: failed to download a banlist from $server" >&2
  exit 1
fi
if [ ! -f $statedir/$statefile ]; then
  touch $statedir/$statefile
  chmod 0600 $statedir/$statefile
fi

diff -q $tempfile $statedir/$statefile > /dev/null 2>&1
if [ $? -eq 1 ]; then
  # there is a difference in the banlist
  if [ $verbose -ge 1 ]; then
    echo "The central banfile was updated:"
    diff -U 0 $statedir/$statefile $tempfile | egrep -v '^(\+\+\+|---|@@)'
  fi

  count=`diff -U 0 $statedir/$statefile $tempfile | egrep -v '^(\+\+\+|---|@@)' | wc -l`
  olddate=`stat -c '%y' $statedir/$statefile |sed -e 's/\..*//'`

  if [ $mailto != "" ]; then
    mail=`mktemp --tmpdir cblist.$$.mail.XXXXXX`
    echo "Subject: CENTRAL BANNING $count changes found from $server" > $mail
    echo "To: $mailto" >> $mail
    echo "From: Central Ban Monitor" >> $mail
    echo "" >> $mail
    echo "The following changes have appeared in the central ban file since it " >> $mail
    echo "was previously updated on $olddate." >> $mail
    echo "" >> $mail
    diff -U 0 $statedir/$statefile $tempfile | egrep -v '^(\+\+\+|---|@@)' >> $mail

    if [ $verbose -ge 3 ]; then
      echo "--- ABOUT TO SEND MAIL ---"
      cat $mail
      echo "--- END OF MAIL ---"
    fi
    if [ `expr match $mailto '.*@.*'` -ne 0 ]; then
      # mail address contains an @, so send it
      sendmail -t < $mail
    fi
  fi

  # update state so we only send once
  cat $tempfile > $statedir/$statefile
else
  if [ $verbose -ne 0 ]; then
    echo "No changes"
  fi
fi
if [ $verbose -ge 2 ]; then
  echo "Current central ban list:"
  cat $statedir/$statefile
fi

rm $tempfile
